*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus

***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         				1
#DEFINE cnOUTPUT_PRINT			         				2
#DEFINE cnOUTPUT_EMAIL			         				3
#DEFINE cnOUTPUT_FILE		 	         				4

***************************************************************************************************************************
*-- IMAGE's output file formats
***************************************************************************************************************************
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_BMP          		1
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_JPG					2
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_GIF					3
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_TIF					4
#DEFINE cnIMAGE_OUTPUT_FILE_FORMAT_PNG					5

***************************************************************************************************************************
*-- Enumeration type that defines the available types of Bar
***************************************************************************************************************************
#DEFINE cnCHART_BARITEM_TYPE_CLUSTER					0
#DEFINE cnCHART_BARITEM_TYPE_OVERLAY					1
#DEFINE cnCHART_BARITEM_TYPE_SORTEDOVERLAY				2
#DEFINE cnCHART_BARITEM_TYPE_STACK						3
#DEFINE cnCHART_BARITEM_TYPE_PERCENTSTACK				4

***************************************************************************************************************************
*-- Enumeration type for the various symbol shapes that are available
***************************************************************************************************************************
#DEFINE cnCHART_SYMBOL_TYPE_SQUARE						0
#DEFINE cnCHART_SYMBOL_TYPE_DIAMOND						1
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE					2
#DEFINE cnCHART_SYMBOL_TYPE_CIRCLE						3
#DEFINE cnCHART_SYMBOL_TYPE_XCROSS						4
#DEFINE cnCHART_SYMBOL_TYPE_PLUS						5
#DEFINE cnCHART_SYMBOL_TYPE_STAR						6
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE_DOWN				7

***************************************************************************************************************************
*-- LinearGradient Mode
***************************************************************************************************************************
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_HORIZONTAL			0
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL			1
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL	2
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_BACKWARDDIAGONAL	3

***************************************************************************************************************************
*-- Enumeration type that defines how a curve is drawn
***************************************************************************************************************************
#DEFINE cnCHART_LINE_STEP_TYPE_FORWARD					0
#DEFINE cnCHART_LINE_STEP_TYPE_REARWARD					1
#DEFINE cnCHART_LINE_STEP_TYPE_NONE						2


LOCAL loFile
LOCAL loChartCurve

LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath

CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

lcOutPutFileName = 'ComboChart'
lcOutPutFilePath = JUSTPATH(SYS(16,0)) + '\OutPut\'

SET PATH TO  ..\..\..\
SET CLASSLIB TO Chart IN FRX2Any.APP ALIAS Chart	

loFile = CREATEOBJ('Chart.ChartFile')


IF TYPE('loFile') = 'O'

	WITH loFile
*-- Unlock FRX2Any
		.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = 'ReportOutput'
		.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = 'c:\MyApp\MyOutPut\'
		.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
		.nOutPutType     = cnOUTPUT_SCREEN

*-- Default value is cnIMAGE_OUTPUT_FILE_FORMAT_GIF
		.nImageFileType  = cnIMAGE_OUTPUT_FILE_FORMAT_PNG

*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.

		WITH .oPanel
*-- Set the main Title of the Chart
			.cTitle 	  = 'Semurg Enterprise' + CHR(10) + 'Production Report (2002 - 2004)'

			.nWidth  = 800
			.nHeight = 550

			WITH .oFontSpec
				.cFamily   = 'Arial Black'
			ENDWITH

			WITH .oPanelFill
*-- Create a linear gradient color-fill
				.SetGradientFill(RGB(255,255,255), RGB(208,224,244), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL)
			ENDWITH

			WITH .oAxisFill
*-- Create a linear gradient color-fill
				.SetGradientFill(RGB(255,255,255), RGB(249, 253, 200), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL)
			ENDWITH

			WITH .oXAxis
*-- Set Title for X axis
				.cTitle = 'Time, Days' + CHR(10) + '(Since Project Startup)'
				.lShowGrid = .T.

				.nScaleMax = 1200
			ENDWITH

			WITH .oYAxis
*-- Set Title for Y axis
				.cTitle = 'Semurg Enterprise Production' + CHR(10) + '(units/hour)'
				.lShowGrid = .T.
			ENDWITH

*-- Add a Curve Item with Circle symbols, and 'Larry' in the legend

*-- Make up some random data points
			DIMENSION laX[11] AS INTEGER

			laX[1]  = 100
			laX[2]  = 200
			laX[3]  = 300
			laX[4]  = 400
			laX[5]  = 500
			laX[6]  = 600
			laX[7]  = 700
			laX[8]  = 800
			laX[9]  = 900
			laX[10] = 1000
			laX[11] = 1100

			DIMENSION laY[11]

			laY[1]  = 20
			laY[2]  = 10
			laY[3]  = 50
			laY[4]  = 25
			laY[5]  = 35
			laY[6]  = 75
			laY[7]  = 90
			laY[8]  = 40
			laY[9]  = 33
			laY[10] = 50
			laY[11] = 45

			loChartCurve = .AddCurve('Johanne', @laX, @laY, RGB(255,55,205), cnCHART_SYMBOL_TYPE_CIRCLE)

			IF !ISNULL(loChartCurve)

				WITH loChartCurve
					WITH .oLine

						.nWidth  = 1.5
						.lSmooth = .T.

						WITH .oFill
							.SetGradientFill(RGB(255,255,255), RGB(255,155,205), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL, 200)
						ENDWITH

					ENDWITH

					WITH .oSymbol
*-- Set the size of the Symbol in pixels
						.nSize = 10

						WITH .oFill
*-- Create a solid color-fill
							.SetSolidFill(RGB(255, 255, 255))
						ENDWITH
					ENDWITH
				ENDWITH

			ENDIF

*-- Add a Curve Item with Triangle symbols, and 'Alex' in the legend

*-- Make up some random data points
			DIMENSION laX[11] AS INTEGER

			laX[1]  = 100
			laX[2]  = 200
			laX[3]  = 300
			laX[4]  = 400
			laX[5]  = 500
			laX[6]  = 600
			laX[7]  = 700
			laX[8]  = 800
			laX[9]  = 900
			laX[10] = 1000
			laX[11] = 1100

			DIMENSION laY[11]

			laY[1]  = 5.2
			laY[2]  = 49.5
			laY[3]  = 10.9
			laY[4]  = 33.9
			laY[5]  = 88.35
			laY[6]  = 99.75
			laY[7]  = 36.90
			laY[8]  = 71.40
			laY[9]  = 43.3
			laY[10] = 65.50
			laY[11] = 25

			loChartCurve = .AddCurve('Marat', @laX, @laY, RGB(0, 128, 0), cnCHART_SYMBOL_TYPE_TRIANGLE)

			IF !ISNULL(loChartCurve)

				WITH loChartCurve
					WITH .oLine

						.nWidth    = 1.5
						.nStepType = cnCHART_LINE_STEP_TYPE_FORWARD

						WITH .oFill
							.SetGradientFill(RGB(255,255,255), RGB(60, 190, 50), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL, 200)
						ENDWITH
					ENDWITH

					WITH .oSymbol
*-- Set the size of the Symbol, value Size in pixels
						.nSize = 10

						WITH .oFill
*-- Create a solid color-fill
							.SetSolidFill(RGB(255, 255, 255))
						ENDWITH
					ENDWITH
				ENDWITH

			ENDIF

*-- Add a Bar Item with 'Murad' in the legend

			.nClusterScaleWidth = 100
			.nBarType 			= cnCHART_BARITEM_TYPE_SORTEDOVERLAY

*-- Make up some random data points
			DIMENSION laX[11] AS INTEGER

			laX[1]  = 100
			laX[2]  = 200
			laX[3]  = 300
			laX[4]  = 400
			laX[5]  = 500
			laX[6]  = 600
			laX[7]  = 700
			laX[8]  = 800
			laX[9]  = 900
			laX[10] = 1000
			laX[11] = 1100

			DIMENSION laY[11]

			laY[1]  = 26
			laY[2]  = 40
			laY[3]  = 50
			laY[4]  = 60
			laY[5]  = 10
			laY[6]  = 90
			laY[7]  = 93
			laY[8]  = 85
			laY[9]  = 75
			laY[10] = 55
			laY[11] = 65

			loChartCurve = .AddBar('Murad', @laX, @laY)

			IF !ISNULL(loChartCurve)

				WITH loChartCurve
					WITH .oBar
						WITH .oFill
							.SetGradientFill(RGB(255, 255, 255), RGB(128,0,64), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL)
						ENDWITH
					ENDWITH
				ENDWITH

			ENDIF


*-- Add a Bar Item with 'Mike' in the legend

*-- Make up some random data points
			DIMENSION laX[11] AS INTEGER

			laX[1]  = 100
			laX[2]  = 200
			laX[3]  = 300
			laX[4]  = 400
			laX[5]  = 500
			laX[6]  = 600
			laX[7]  = 700
			laX[8]  = 800
			laX[9]  = 900
			laX[10] = 1000
			laX[11] = 1100

			DIMENSION laY[11]

			laY[1]  = 40
			laY[2]  = 60
			laY[3]  = 70
			laY[4]  = 80
			laY[5]  = 85
			laY[6]  = 30
			laY[7]  = 60
			laY[8]  = 50
			laY[9]  = 95
			laY[10] = 75
			laY[11] = 35

			loChartCurve = .AddBar('Mike', @laX, @laY)

			IF !ISNULL(loChartCurve)

				WITH loChartCurve
					WITH .oBar
						WITH .oFill
							.SetGradientFill(RGB(255, 255, 255), RGB(184,113,255), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL)
						ENDWITH
					ENDWITH
				ENDWITH

			ENDIF

		ENDWITH

		.SAVE()

		.RELEASE()

	ENDWITH

ENDIF

